/**
 * The standard enum type
 */
type StandardEnum<T> = {
    [id: string]: T | string;
    [nu: number]: string;
};
/**
 * Returns the name of an enum from its value
 * @param enumVariable The enum for which you want to get the name
 * @param enumValue The value of the enum for which you want to get the name
 * @returns A string containing the name of the enum
 */
declare function getEnumNameFromValue<T>(enumVariable: StandardEnum<T>, enumValue: T): string;
/**
 * Returns the value of an enum from its name
 * @param enumVariable The enum for which you want to get the value
 * @param enumName The name of the enum for which you want to get the value
 * @returns A string containing the value of the enum
 */
export declare function getEnumValueFromName<T>(enumVariable: StandardEnum<T>, enumName: string): number | string;
/**
 * Returns all the names of an enum
 * @param enumVariable The enum for which you want to get the names
 * @returns A string array containing the names of the enum
 */
export declare function getEnumNames<T>(enumVariable: StandardEnum<T>): (string | T)[];
/**
 * Returns all the values of an enum
 * @param enumVariable The enum for which you want to get the values
 * @returns A string or number array containing the values of the enum
 */
export declare function getEnumValues<T>(enumVariable: StandardEnum<T>): (string | T)[] | number[];
export { getEnumNameFromValue };
